@@ -4,6 +4,8 @@ from cerberus import errors
 import operator
 import typing
 import hamcrest as matchers
+
+from assertman import datetimes
 from assertman.helpers.datetime_helper import DateTimeApi
 
 
@@ -324,10 +326,10 @@ class SkyrimValidator(Validator):
         expected_result, not_, matcher = self._unwrap(matcher)
         message = matcher.get("message")
         if self.__hamcrest_assert_that(
-                value, matchers.is_today_with_shift(**{k: v for k, v in matcher.items() if k != "message"})) \
+                value, datetimes.is_today_with_shift(**{k: v for k, v in matcher.items() if k != "message"})) \
                 != expected_result:
             self._error(field, f"Expected: {not_}{message}, "
-                               f"but was: <{DateTimeApi(value).to_sdp_format()}>")
+                               f"but was: <{DateTimeApi(value).to_datetime_format()}>")
 
     def _validate_is_greater_than_datetime(self, matcher, field, value):
         """
@@ -335,10 +337,10 @@ class SkyrimValidator(Validator):
         """
         expected_result, not_, matcher = self._unwrap(matcher)
 
-        if self.__hamcrest_assert_that(value, matchers.is_greater_than_datetime(matcher)) != expected_result:
+        if self.__hamcrest_assert_that(value, datetimes.is_greater_than_datetime(matcher)) != expected_result:
             self._error(field, f"Must {not_}be greater "
-                               f"than <{DateTimeApi(matcher).to_sdp_format()}>, "
-                               f"but was: <{DateTimeApi(value).to_sdp_format()}> "
+                               f"than <{DateTimeApi(matcher).to_datetime_format()}>, "
+                               f"but was: <{DateTimeApi(value).to_datetime_format()}> "
                                f"is {'not ' if not not_ else ''}greater")
 
     def _validate_is_less_than_datetime(self, matcher, field, value):
@@ -347,10 +349,10 @@ class SkyrimValidator(Validator):
         """
         expected_result, not_, matcher = self._unwrap(matcher)
 
-        if self.__hamcrest_assert_that(value, matchers.is_less_than_datetime(matcher)) != expected_result:
+        if self.__hamcrest_assert_that(value, datetimes.is_less_than_datetime(matcher)) != expected_result:
             self._error(field, f"Must {not_}be less "
-                               f"than <{DateTimeApi(matcher).to_sdp_format()}>, "
-                               f"but was: <{DateTimeApi(value).to_sdp_format()}> "
+                               f"than <{DateTimeApi(matcher).to_datetime_format()}>, "
+                               f"but was: <{DateTimeApi(value).to_datetime_format()}> "
                                f"is {'not ' if not not_ else ''}less")
 
     def _validate_is_equal_to_datetime(self, matcher, field, value):
@@ -359,9 +361,9 @@ class SkyrimValidator(Validator):
         """
         expected_result, not_, matcher = self._unwrap(matcher)
 
-        if self.__hamcrest_assert_that(value, matchers.is_equal_to_datetime(matcher)) != expected_result:
-            self._error(field, f"Must {not_}be equal to <{DateTimeApi(matcher).to_sdp_format()}>, "
-                               f"but was: <{DateTimeApi(value).to_sdp_format()}>")
+        if self.__hamcrest_assert_that(value, datetimes.is_equal_to_datetime(matcher)) != expected_result:
+            self._error(field, f"Must {not_}be equal to <{DateTimeApi(matcher).to_datetime_format()}>, "
+                               f"but was: <{DateTimeApi(value).to_datetime_format()}>")
 
     def _validate_is_greater_than_date(self, matcher, field, value):
         """
@@ -369,10 +371,10 @@ class SkyrimValidator(Validator):
         """
         expected_result, not_, matcher = self._unwrap(matcher)
 
-        if self.__hamcrest_assert_that(value, matchers.is_greater_than_date(matcher)) != expected_result:
+        if self.__hamcrest_assert_that(value, datetimes.is_greater_than_date(matcher)) != expected_result:
             self._error(field, f"Must {not_}be greater "
-                               f"than <{DateTimeApi(matcher).to_sdp_format()}>, "
-                               f"but was: <{DateTimeApi(value).to_sdp_format()}> "
+                               f"than <{DateTimeApi(matcher).to_datetime_format()}>, "
+                               f"but was: <{DateTimeApi(value).to_datetime_format()}> "
                                f"is {'not ' if not not_ else ''}greater (ignoring time)")
 
     def _validate_is_less_than_date(self, matcher, field, value):
@@ -381,10 +383,10 @@ class SkyrimValidator(Validator):
         """
         expected_result, not_, matcher = self._unwrap(matcher)
 
-        if self.__hamcrest_assert_that(value, matchers.is_less_than_date(matcher)) != expected_result:
+        if self.__hamcrest_assert_that(value, datetimes.is_less_than_date(matcher)) != expected_result:
             self._error(field, f"Must {not_}be less "
-                               f"than <{DateTimeApi(matcher).to_sdp_format()}>, "
-                               f"but was: <{DateTimeApi(value).to_sdp_format()}> "
+                               f"than <{DateTimeApi(matcher).to_datetime_format()}>, "
+                               f"but was: <{DateTimeApi(value).to_datetime_format()}> "
                                f"is {'not ' if not not_ else ''}less (ignoring time)")
 
     def _validate_is_equal_to_date(self, matcher, field, value):
@@ -393,9 +395,9 @@ class SkyrimValidator(Validator):
         """
         expected_result, not_, matcher = self._unwrap(matcher)
 
-        if self.__hamcrest_assert_that(value, matchers.is_equal_to_date(matcher)) != expected_result:
-            self._error(field, f"Must {not_}be equal to <{DateTimeApi(matcher).to_sdp_format()}>, "
-                               f"but was: <{DateTimeApi(value).to_sdp_format()}> (ignoring time)")
+        if self.__hamcrest_assert_that(value, datetimes.is_equal_to_date(matcher)) != expected_result:
+            self._error(field, f"Must {not_}be equal to <{DateTimeApi(matcher).to_datetime_format()}>, "
+                               f"but was: <{DateTimeApi(value).to_datetime_format()}> (ignoring time)")
 
     def _validate_is_equal_to_date_ignoring_seconds(self, matcher, field, value):
         """
@@ -404,8 +406,8 @@ class SkyrimValidator(Validator):
         expected_result, not_, matcher = self._unwrap(matcher)
 
         if self.__hamcrest_assert_that(
-                value, matchers.is_equal_to_date_ignoring_seconds(matcher["value"], matcher["seconds"])) \
+                value, datetimes.close_to_datetime(matcher["value"], matcher["seconds"])) \
                 != expected_result:
-            self._error(field, f"Must {not_}be equal to <{DateTimeApi(matcher['value']).to_sdp_format()}>, "
-                               f"but was: <{DateTimeApi(value).to_sdp_format()}> "
+            self._error(field, f"Must {not_}be equal to <{DateTimeApi(matcher['value']).to_datetime_format()}>, "
+                               f"but was: <{DateTimeApi(value).to_datetime_format()}> "
                                f"(ignoring {matcher['seconds']} seconds)")
