@@ -4,4 +4,4 @@ from assertman.matchers.text import *
 from assertman.matchers.sequence import *
 from assertman.matchers.dictionary import *
 from assertman.matchers.logical import *
-# from assertman.matchers.datetime import *
\ No newline at end of file
+from assertman.matchers.datetimes import *
\ No newline at end of file
