@@ -1,3 +1,4 @@
+from assertman.assertable_mixin import AssertableMixin
 from assertman.objects.assertable_string import AssertableString
 from assertman.objects.assertable_list import AssertableList
 from assertman.objects.assertable_dict import AssertableDict
@@ -10,7 +11,7 @@ import datetime
 
 
 def make_assertable_object(arg):
-    if isinstance(arg, (bool, AssertableBool)):
+    if isinstance(arg, bool):
         return AssertableBool(arg)
     if isinstance(arg, str):
         return AssertableString(arg)
@@ -26,4 +27,6 @@ def make_assertable_object(arg):
         return AssertableDatetime(arg)
     elif arg is None:
         return AssertableNone(arg)
+    elif AssertableMixin in type(arg).__bases__:
+        return arg
     raise ValueError(f"Для переданнного типа даннных <{type(arg)}> нет маппинга")
\ No newline at end of file
